pub fn ensure_terraphim_block_ids(
markdown: &str,
) -> Result<String, MarkdownParserError>Expand description
Ensure every list item and paragraph has a stable Terraphim block id.
Canonical forms:
- Paragraph:
<!-- terraphim:block-id:<ULID> -->on its own line immediately before the paragraph - List item: inline after the marker (and optional task checkbox), e.g.
- <!-- terraphim:block-id:<ULID> --> text