pub struct Block {
pub id: Ulid,
pub kind: BlockKind,
pub span: Range<usize>,
pub id_span: Range<usize>,
}Fields
id: Ulidkind: BlockKindspan: Range<usize>Byte span of the block in the markdown buffer.
For paragraphs, this includes the block-id comment line plus the paragraph content. For list items, this includes the full list item (including nested content).
id_span: Range<usize>Byte span of the block-id anchor.
For paragraphs, this is the full comment line (including any leading quote/indent prefix). For list items, this is the inline HTML comment inside the list item’s first line.